==> haskell-temporary-1.3-763-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 temporary
version:              1.3
visibility:           public
id:                   temporary-1.3-PDEW3NiP5RF98HJ5wXFiq
key:                  temporary-1.3-PDEW3NiP5RF98HJ5wXFiq
license:              BSD-3-Clause
maintainer:
    Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>

homepage:             https://github.com/feuerbach/temporary
synopsis:             Portable temporary file and directory support
description:          Functions for creating temporary files and directories.
category:             System, Utils
abi:                  e8bdd874ea8924870f95492ec2db30d6
exposed:              True
exposed-modules:      System.IO.Temp
import-dirs:          /usr/lib/ghc-9.4.8/site-local/temporary-1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/temporary-1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/temporary-1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-temporary
hs-libraries:         HStemporary-1.3-PDEW3NiP5RF98HJ5wXFiq
depends:
    base-4.17.2.1 directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    random-1.2.1.3-9I8x2ZdyyN6LUBxcAUCXuW transformers-0.5.6.2
    unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html:         /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-temporary-1.3-765-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 temporary
version:              1.3
visibility:           public
id:                   temporary-1.3-CMXzj4FJK6R7txKYLvk1Gk
key:                  temporary-1.3-CMXzj4FJK6R7txKYLvk1Gk
license:              BSD-3-Clause
maintainer:
    Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>

homepage:             https://github.com/feuerbach/temporary
synopsis:             Portable temporary file and directory support
description:          Functions for creating temporary files and directories.
category:             System, Utils
abi:                  b7522391001410f936fe6d120d95e657
exposed:              True
exposed-modules:      System.IO.Temp
import-dirs:          /usr/lib/ghc-9.4.8/site-local/temporary-1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/temporary-1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/temporary-1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-temporary
hs-libraries:         HStemporary-1.3-CMXzj4FJK6R7txKYLvk1Gk
depends:
    base-4.17.2.1 directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    random-1.2.1.3-5ACjslZ7ju38gzfSozRJEo transformers-0.5.6.2
    unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html:         /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
